## 3.5.2.13 (2023-07-15)

[stripe] Add type for PaymentLink (#10461)

## 3.5.2.12 (2023-07-06)

Stripe: add shipping_rate to `__init__.py` (#10416)

## 3.5.2.11 (2023-07-06)

stripe: add shipping_rate type (#10323)

* add shipping_rate type

* remove redundant method

## 3.5.2.10 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 3.5.2.9 (2023-03-28)

Add defaults for third-party stubs Q-T (#9959)

## 3.5.2.8 (2023-02-27)

[stripe] Add Session.expire() (#9814)

## 3.5.2.7 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 3.5.2.6 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 3.5.2.5 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 3.5.2.4 (2022-11-23)

Mark first argument of `__[get|set|del]attr__` as `str` (#9245)

## 3.5.2.3 (2022-11-14)

stripe: fix test clocks imports (#9137)

## 3.5.2.2 (2022-11-09)

Annotate known magic-method return types (#9131)

## 3.5.2.1 (2022-10-31)

stripe: test clocks resource (#9026)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 3.5.2 (2022-09-13)

`stripe`: Add `SearchableAPIResource`, `SearchResultObject` (#8696)

## 3.5.1 (2022-08-08)

Add classmethod to stripe.PaymentIntent.confirm. (#8498)

Signed-off-by: Zixuan James Li <p359101898@gmail.com>

## 3.5.0 (2022-07-01)

[stubsabot] Bump stripe to 3.5.* (#8223)

Co-authored-by: hauntsaninja <>

[stubsabot] Bump stripe to 3.4.* (#8212)

Co-authored-by: hauntsaninja <>

## 2.59.10 (2022-06-03)

`stripe`: update a few signatures (#7978)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 2.59.9 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 2.59.8 (2022-02-28)

Add stripe.util.convert_to_stripe_object (#7386)

## 2.59.7 (2022-02-25)

Improve annotation for stripe DeletableAPIResource delete method (#7230)

## 2.59.6 (2022-02-07)

Improve a bunch of `__(deep)copy__` methods (#7148)

## 2.59.5 (2022-01-31)

Upgrade black version (#7089)

## 2.59.3 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.59.2 (2021-12-21)

add stripe.util.populate_headers (#6637)

fill out api methods for stripe.Customer (#6638)

fill out api stubs for stripe.Account (#6639)

fill out api stubs for stripe.SubscriptionItem (#6640)

## 2.59.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

